==> monica-4.0.0p0.tgz: www/monica/resources/lang/fr/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Comment s’est passé votre journée ? Vous pouvez voter une fois par jour.',
    'journal_come_back' => 'Merci. Revenez demain pour voter à nouveau.',
    'journal_description' => 'Note : le journal liste les entrées manuelles, ainsi que les entrées automatiques comme les activités que vous faites avec vos contacts. Bien que vous puissiez supprimer les entrées manuelles, vous devrez supprimer les activités directement de la page du contact pour les supprimer du journal.',
    'journal_add' => 'Ajouter une entrée',
    'journal_edit' => 'Éditer une entrée de journal',
    'journal_empty' => 'Journal vide',
    'journal_created_at' => 'Créé le {date}',
    'journal_created_automatically' => 'Créée automatiquement',
    'journal_entry_type_journal' => 'Note de journal',
    'journal_entry_type_activity' => 'Activité',
    'journal_entry_rate' => 'Vous avez évalué votre journée.',
    'journal_add_comment' => 'Ajouter un commentaire (optionnel) ?',
    'journal_show_comment' => 'Afficher le commentaire',
    'entry_delete_success' => 'L’entrée a été supprimée avec succès.',
    'journal_add_title' => 'Titre (optionnel)',
    'journal_add_date' => 'Date',
    'journal_add_post' => 'Entrée',
    'journal_add_cta' => 'Sauvegarder',
    'journal_blank_cta' => 'Ajouter votre première entrée dans le journal',
    'journal_blank_description' => 'Le journal vous permet de vous rappeler d’évènements passés, ou à venir.',
    'delete_confirmation' => 'Êtes-vous sûr de vouloir supprimer cette entrée ?',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/fr/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Comment s’est passé votre journée ? Vous pouvez voter une fois par jour.',
    'journal_come_back' => 'Merci. Revenez demain pour voter à nouveau.',
    'journal_description' => 'Note : le journal liste les entrées manuelles, ainsi que les entrées automatiques comme les activités que vous faites avec vos contacts. Bien que vous puissiez supprimer les entrées manuelles, vous devrez supprimer les activités directement de la page du contact pour les supprimer du journal.',
    'journal_add' => 'Ajouter une entrée',
    'journal_edit' => 'Éditer une entrée de journal',
    'journal_empty' => 'Journal vide',
    'journal_created_at' => 'Créé le {date}',
    'journal_created_automatically' => 'Créée automatiquement',
    'journal_entry_type_journal' => 'Note de journal',
    'journal_entry_type_activity' => 'Activité',
    'journal_entry_rate' => 'Vous avez évalué votre journée.',
    'journal_add_comment' => 'Ajouter un commentaire (optionnel) ?',
    'journal_show_comment' => 'Afficher le commentaire',
    'entry_delete_success' => 'L’entrée a été supprimée avec succès.',
    'journal_add_title' => 'Titre (optionnel)',
    'journal_add_date' => 'Date',
    'journal_add_post' => 'Entrée',
    'journal_add_cta' => 'Sauvegarder',
    'journal_blank_cta' => 'Ajouter votre première entrée dans le journal',
    'journal_blank_description' => 'Le journal vous permet de vous rappeler d’évènements passés, ou à venir.',
    'delete_confirmation' => 'Êtes-vous sûr de vouloir supprimer cette entrée ?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
